function [X,f,a] = expsin(c,n,delta)
%function [X,f] = expsin(c,n,delta)

%  c:     Parametro que representa la altura del cilindro
%  n:     Parametro que representa el termino
%  delta: Caracterizacion de la exponencial en Z

    k=1;

    for x=0:0.001:c
    
        f(k) = sin(n*pi*x/c)*exp(-1*((x-c/2)^2)/delta);
        k = k+1;
   
    end
    
    X=0:0.001:c;
    
    %plot(X,f);
    a=area(X,f);